@@ -147,6 +147,7 @@ COMMON_EXCEPTIONS = dict((re.compile(x), [re.compile(z) if isinstance(z, str) el
 	("^apt.cache.FetchFailedException: E:The repository 'http://localhost/univention-repository.* Release' is not signed.", None),
 	('ImportError: No module named client', ['univention-directory-listener/system/faillog.py']),  # Bug #53290
 	(re.escape("AttributeError: 'ConfigRegistry' object has no attribute '_walk'"), ['univention-directory-listener/system/nfs-shares.py']),  # Bug #53291
+	("univention.lib.umc.ConnectionError: .*Could not send request.*Connection refused", ['univention-self-service-invitation']),  # Bug #53670
 
 	# updater test cases:
 	('urllib.error.URLError: .*', ['updater/tools.py.*in access']),
@@ -162,6 +163,7 @@ COMMON_EXCEPTIONS = dict((re.compile(x), [re.compile(z) if isinstance(z, str) el
 	# 10_ldap/listener_module_testpy
 	('MyTestException: .*', None),
 	# various test cases:
+	('AssertionError: .*contain.*traceback', ['01_var_log_tracebacks']),
 	('^(univention.management.console.modules.ucstest.)?NonThreadedError$', None),
 	(r'^(ldap\.)?INVALID_SYNTAX: .*ABCDEFGHIJKLMNOPQRSTUVWXYZ.*', ['sync_from_ucs']),
 	(r'^(ldap\.)?INVALID_SYNTAX: .*telephoneNumber.*', ['sync_from_ucs']),  # Bug #35391 52_s4connector/134sync_incomplete_attribute_ucs
@@ -179,18 +181,24 @@ COMMON_EXCEPTIONS = dict((re.compile(x), [re.compile(z) if isinstance(z, str) el
 	# UCS@school test cases:
 	# ("ucsschool.importer.exceptions.InitialisationError: Value of 'scheme:description' must be a string.", ['in prepare_import']),  # Bug #53564
 	("ucsschool.importer.exceptions.ConfigurationError: Columns configured in csv:mapping missing:", ['in read_input']),  # Bug #53564
-	("ValueError: time data '19010203' does not match format '%Y-%m-%d'", ['import_user.py.* in validate']),  # Bug #53564
+	("ValueError: time data '.*' does not match format '%Y-%m-%d'", ['import_user.py.* in validate']),  # Bug #53564
 	("ucsschool.importer.exceptions.InitialisationError: Recursion detected when resolving formatting dependencies for 'email'.", ['user_import.py.* in read_input']),  # Bug #53564
 	("ucsschool.importer.exceptions.InvalidBirthday: Birthday has invalid format: '.*' error: time data '.*' does not match format '%Y-%m-%d'.", ['user_import.py.* in create_and_modify_users']),  # Bug #53564
 	("ucsschool.importer.exceptions.UcsSchoolImportSkipImportRecord: Skipping user '.*' with firstname starting with \".\"", ['user_import.py.* in create_and_modify_users']),  # Bug #53564
-	("ucsschool.importer.exceptions.TooManyErrors: More than 0 errors.", ['cmdline.py.* in main']),  # Bug #53564
-	("ucsschool.importer.exceptions.InitialisationError: Configuration value of username:max_length:default is .*, but must not be higher than UCR variable ucsschool/username/max_length (20).", ['in prepare_import']),  # Bug #53564
+	("ucsschool.importer.exceptions.TooManyErrors: More than 0 errors.", ['cmdline.py.* in main', 'in import_users']),  # Bug #53564
+	(r"ucsschool.importer.exceptions.InitialisationError: Configuration value of username:max_length:default is .*, but must not be higher than UCR variable ucsschool/username/max_length \(20\).", ['in prepare_import']),  # Bug #53564
 	("ucsschool.importer.exceptions.InitialisationError: The 'user_deletion' configuration key is deprecated. Please set 'deletion_grace_period'.", ['in prepare_import']),  # Bug #53564
 	("ucsschool.importer.exceptions.InitialisationError: Thou shalt not import birthdays!", ['in prepare_import']),  # Bug #53564
 	("ucsschool.importer.exceptions.InitialisationError: Deprecated configuration key 'scheme:username:allow_rename'.", ['in prepare_import']),  # Bug #53564
 	("ucsschool.importer.exceptions.InitialisationError: Value of 'scheme:.*' must be a string.", ['in prepare_import']),  # Bug #53564
 	("ucsschool.importer.exceptions.MoveError: Error moving.*from school 'NoSchool' to", ['in create_and_modify_users']),  # Bug #53564
+	("ucsschool.importer.exceptions.UniqueIdError: Username '.*' is already in use by .*", ['in create_and_modify_users']),  # Bug #53564
+	('ucsschool.importer.exceptions.UserValidationError: <unprintable UserValidationError object>', ['in create_and_modify_users']),  # Bug #53564
 	("Exception: Empty user.input_data.", ['test228_input_data_pyhook.py']),  # Bug #53564
+	("ConnectionForced:.*broker forced connection closure with reason .*shutdown", ['celery']),  # Bug #53564
+	(r"error: \[Errno 104\] Connection reset by peer", ['celery']),  # Bug #53671 Bug #53564
+	(r"ConnectionResetError: \[Errno 104\] Connection reset by peer", ['celery']),  # Bug #53671 Bug #53564
+	("gunicorn.errors.HaltServer:.*Worker failed to boot", ['gunicorn']),  # Bug #53564
 	# Tracebacks caused by specific bugs:
 	(r'^ldap\.NO_SUCH_OBJECT: .*', [r'quota\.py']),  # Bug #52765
 	(r'.*OperationalError.*FATAL:.*admindiary.*', [r'admindiary_backend_wrapper\.py', '_wrap_pool_connect']),  # Bug #51671
@@ -239,9 +247,14 @@ COMMON_EXCEPTIONS = dict((re.compile(x), [re.compile(z) if isinstance(z, str) el
 	('ldap.NO_SUCH_OBJECT', ['_add_all_shares_below_this_container_to_dn_list']),  # Bug #43171
 	(re.escape('LISTENER    ( PROCESS ) : updating') + '.*command a', ['cleanup_python_moduledir']),  # ...
 	('ldap.ALREADY_EXISTS.*as it is still the primaryGroupID', ['in sync_from_ucs']),  # Bug #53278
+	('ldap.NOT_ALLOWED_ON_NONLEAF:.*Unable to delete a non-leaf node .*it has .* child', ['in delete_in_s4']),  # Bug #53278
 	('univention.admin.uexceptions.valueError: The domain part of the primary mail address is not in list of configured mail domains:', ['in sync_to_ucs']),  # Bug #53277
 	(r"subprocess.CalledProcessError: Command '\('rndc', 'reconfig'\)' returned non-zero exit status 1", ['univention-fix-ucr-dns']),  # Bug #53332
 	(r"ldap.NO_SUCH_OBJECT: .*objectclass: Cannot add cn=(user|machine),cn=\{[0-9a-f-]+\},cn=policies,cn=system,DC=.*parent does not exist", ['in sync_from_ucs']),  # Bug #53334
+	("TypeError: 'NoneType' object is not subscriptable", ['primary_group_sync_to_ucs', 'add_primary_group_to_addlist']),  # Bug #53276
+	("CONSTRAINT_VIOLATION: .*Failed to re-index objectSid in .*unique index violation on objectSid", ['python2.7.*sync_from_ucs']),  # Bug #53720
+	('ldap.REFERRAL:.*', ['uldap.py']),  # Bug #53721
+	('ldap.INSUFFICIENT_ACCESS:.*', ['in password_sync_s4_to_ucs']),  # Bug #53721
 ])
 
 
