@@ -32,6 +32,7 @@ Common functions used by tests.
 from __future__ import print_function
 
 import functools
+import inspect
 import os
 import socket
 import subprocess
@@ -105,9 +106,9 @@ class UCSTestDomainAdminCredentials(object):
 			ucr = UCR
 			ucr.load()
 		self.binddn = ucr.get('tests/domainadmin/account', 'uid=Administrator,cn=users,%(ldap/base)s' % ucr)
-		pwdfile = ucr.get('tests/domainadmin/pwdfile')
-		if pwdfile:
-			with open(pwdfile, 'r') as f:
+		self.pwdfile = ucr.get('tests/domainadmin/pwdfile')
+		if self.pwdfile:
+			with open(self.pwdfile, 'r') as f:
 				self.bindpw = f.read().strip('\n\r')
 		else:
 			self.bindpw = ucr.get('tests/domainadmin/pwd', 'univention')
@@ -117,30 +118,27 @@ class UCSTestDomainAdminCredentials(object):
 			self.username = None
 
 
-def get_ldap_connection(pwdfile=False, start_tls=2, decode_ignorelist=None, admin_uldap=False):
-	# type: (bool, int, Optional[List[Text]], bool) -> access
-	if decode_ignorelist is None:
-		decode_ignorelist = []
+def get_ldap_connection(admin_uldap=False, primary=False):
+	# type: (Optional[bool], Optional[bool]) -> access
 	ucr = UCR
 	ucr.load()
 
-	port = int(ucr.get('ldap/server/port', 7389))
-	binddn = ucr.get('tests/domainadmin/account', 'uid=Administrator,cn=users,%(ldap/base)s' % ucr)
-	ldapServers = []
-	if ucr['ldap/server/name']:
-		ldapServers.append(ucr['ldap/server/name'])
-	if ucr['ldap/servers/addition']:
-		ldapServers.extend(ucr['ldap/server/addition'].split())
-
-	if pwdfile:
-		with open(ucr['tests/domainadmin/pwdfile']) as f:
-			bindpw = f.read().strip('\n')
+	if primary:
+		port = int(ucr.get('ldap/master/port', 7389))
+		ldap_servers = [ucr['ldap/master']]
 	else:
-		bindpw = ucr['tests/domainadmin/pwd']
+		port = int(ucr.get('ldap/server/port', 7389))
+		ldap_servers = []
+		if ucr['ldap/server/name']:
+			ldap_servers.append(ucr['ldap/server/name'])
+		if ucr['ldap/servers/addition']:
+			ldap_servers.extend(ucr['ldap/server/addition'].split())
 
-	for ldapServer in ldapServers:
+	creds = UCSTestDomainAdminCredentials()
+
+	for ldap_server in ldap_servers:
 		try:
-			lo = uldap.access(host=ldapServer, port=port, base=ucr['ldap/base'], binddn=binddn, bindpw=bindpw, start_tls=start_tls, decode_ignorelist=decode_ignorelist, follow_referral=True)
+			lo = uldap.access(host=ldap_server, port=port, base=ucr['ldap/base'], binddn=creds.binddn, bindpw=creds.bindpw, start_tls=2, decode_ignorelist=[], follow_referral=True)
 			if admin_uldap:
 				lo = access(lo=lo)
 			return lo
@@ -150,7 +148,7 @@ def get_ldap_connection(pwdfile=False, start_tls=2, decode_ignorelist=None, admi
 
 
 def retry_on_error(func, exceptions=(Exception,), retry_count=20, delay=10):
-	# type: (Callable, Tuple[Type[Exception], ...], int, Union[float, int]) -> Any
+	# type: (Callable[[...], ...], Tuple[Type[Exception], ...], int, Union[float, int]) -> Any
 	"""
 	This function calls the given function `func`.
 	If one of the specified `exceptions` is caught, `func` is called again until
@@ -173,32 +171,66 @@ def retry_on_error(func, exceptions=(Exception,), retry_count=20, delay=10):
 				time.sleep(delay)
 			else:
 				print('Exception occurred: %s (%s). This was the last retry (retry %d/%d).' % (exc_info[0], exc_info[1], i, retry_count))
-		else:
-			break
 	else:
 		six.reraise(*exc_info)
 
 
-def verify_ldap_object(baseDn, expected_attr=None, strict=True, should_exist=True, retry_count=20, delay=10):
-	# type: (str, Optional[Dict[str, str]], bool, bool, int, float) -> None
+def verify_ldap_object(
+	baseDn,  # type: str
+	expected_attr=None,  # type: Optional[Dict[str, str]]
+	strict=True,  # type: Optional[bool]
+	should_exist=True,  # type: Optional[bool]
+	retry_count=20,  # type: Optional[int]
+	delay=10,  # type: Optional[float]
+	primary=False,  # type: Optional[bool]
+	pre_check=None,  # type: Optional[Callable[[...], ...]]
+	pre_check_kwargs=None,  # type: Optional[Dict[str, Any]]
+):  # type: (...) -> None
+	"""
+	Verify [non]existence and attributes of LDAP object.
+
+	:param str baseDn: DN of object to check
+	:param dict expected_attr: attributes and their values that the LDAP object is expected to have
+	:param bool strict: value lists of multi-value attributes must be complete
+	:param bool should_exist: whether the object is expected to exist
+	:param int retry_count: how often to retry the verification if it fails before raising an exception
+	:param float delay: waiting time in seconds between retries on verification failures
+	:param bool primary: whether to connect to the primary (DC master) instead of local LDAP (to be
+		exact: ucr[ldap/server/name], ucr['ldap/server/addition'])
+	:param pre_check: function to execute before starting verification. Value should be a function object
+		like `utils.wait_for_replication`.
+	:param dict pre_check_kwargs: dict with kwargs to pass to `pre_check()` call
+	:return: None
+	:raises LDAPObjectNotFound: when no object was found at `baseDn`
+	:raises LDAPUnexpectedObjectFound: when an object was found at `baseDn`, but `should_exist=False`
+	:raises LDAPObjectValueMissing: when a value listed in `expected_attr` is missing in the LDAP object
+	:raises LDAPObjectUnexpectedValue: if `strict=True` and a multi-value attribute of the LDAP object
+		has more values than were listed in `expected_attr`
+	:raises TypeError: if the value of `pre_check` is not a function object
+	"""
 	ucr = UCR
 	ucr.load()
 	retry_count = int(ucr.get("tests/verify_ldap_object/retry_count", retry_count))
 	delay = int(ucr.get("tests/verify_ldap_object/delay", delay))
 
+	if pre_check:
+		if not inspect.isfunction(pre_check) or inspect.ismethod(pre_check):
+			raise TypeError("Value of argument 'pre_check' is not a function: {!r}".format(pre_check))
+		pre_check(**(pre_check_kwargs or {}))
+
 	return retry_on_error(
-		functools.partial(__verify_ldap_object, baseDn, expected_attr, strict, should_exist),
+		functools.partial(__verify_ldap_object, baseDn, expected_attr, strict, should_exist, primary),
 		(LDAPUnexpectedObjectFound, LDAPObjectNotFound, LDAPObjectValueMissing),
 		retry_count,
 		delay)
 
 
-def __verify_ldap_object(baseDn, expected_attr=None, strict=True, should_exist=True):
-	# type: (str, Optional[Dict[str, str]], bool, bool) -> None
+def __verify_ldap_object(baseDn, expected_attr=None, strict=True, should_exist=True, primary=False):
+	# type: (str, Optional[Dict[str, str]], Optional[bool], Optional[bool], Optional[bool]) -> None
 	if expected_attr is None:
 		expected_attr = {}
 	try:
-		dn, attr = get_ldap_connection().search(
+		dn, attr = get_ldap_connection(primary=primary).search(
 			filter='(objectClass=*)',
 			base=baseDn,
 			scope=ldap.SCOPE_BASE,
@@ -489,12 +521,16 @@ def wait_for(conditions=None, verbose=True):
 				# TODO: search in OpenLDAP with filter=detail
 				pass
 		elif replicationtype == ReplicationType.DRS:
-			from univention.testing.ucs_samba import wait_for_drs_replication
 			if not isinstance(detail, dict):
 				detail = {'ldap_filter': detail}
 			wait_for_drs_replication(verbose=verbose, **detail)
 
 
+def wait_for_drs_replication(*args, **kwargs):
+	from univention.testing.ucs_samba import wait_for_drs_replication
+	return wait_for_drs_replication(*args, **kwargs)
+
+
 def wait_for_listener_replication(verbose=True):
 	# type: (bool) -> None
 	sys.stdout.flush()
